@@ -1,5 +1,5 @@
 /*
-    GNOME Commander - A GNOME based file manager 
+    GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
 
     This program is free software; you can redistribute it and/or modify
@@ -14,19 +14,22 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-*/ 
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
+*/
+
 #ifndef __GNOME_CMD_MKDIR_DIALOG_H__
 #define __GNOME_CMD_MKDIR_DIALOG_H__
 
 #include "gnome-cmd-dir.h"
 
+G_BEGIN_DECLS
+
 #define GNOME_CMD_MKDIR_DIALOG(obj) \
-	GTK_CHECK_CAST (obj, gnome_cmd_mkdir_dialog_get_type (), GnomeCmdMkdirDialog)
+    GTK_CHECK_CAST (obj, gnome_cmd_mkdir_dialog_get_type (), GnomeCmdMkdirDialog)
 #define GNOME_CMD_MKDIR_DIALOG_CLASS(klass) \
-	GTK_CHECK_CLASS_CAST (klass, gnome_cmd_mkdir_dialog_get_type (), GnomeCmdMkdirDialogClass)
+    GTK_CHECK_CLASS_CAST (klass, gnome_cmd_mkdir_dialog_get_type (), GnomeCmdMkdirDialogClass)
 #define GNOME_CMD_IS_MKDIR_DIALOG(obj) \
-	GTK_CHECK_TYPE (obj, gnome_cmd_mkdir_dialog_get_type ())
+    GTK_CHECK_TYPE (obj, gnome_cmd_mkdir_dialog_get_type ())
 
 
 typedef struct _GnomeCmdMkdirDialog GnomeCmdMkdirDialog;
@@ -37,14 +40,14 @@ typedef struct _GnomeCmdMkdirDialogClass GnomeCmdMkdirDialogClass;
 
 struct _GnomeCmdMkdirDialog
 {
-	GnomeCmdStringDialog parent;
-	GnomeCmdMkdirDialogPrivate *priv;
+    GnomeCmdStringDialog parent;
+    GnomeCmdMkdirDialogPrivate *priv;
 };
 
 
 struct _GnomeCmdMkdirDialogClass
 {
-	GnomeCmdStringDialogClass parent_class;
+    GnomeCmdStringDialogClass parent_class;
 };
 
 
@@ -54,9 +57,6 @@ gnome_cmd_mkdir_dialog_new (GnomeCmdDir *dir);
 GtkType
 gnome_cmd_mkdir_dialog_get_type (void);
 
+G_END_DECLS
 
-
-
-#endif //__GNOME_CMD_MKDIR_DIALOG_H__
-
-
+#endif // __GNOME_CMD_MKDIR_DIALOG_H__
