@@ -1,5 +1,5 @@
 /*
-    GNOME Commander - A GNOME based file manager 
+    GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
 
     This program is free software; you can redistribute it and/or modify
@@ -14,21 +14,26 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-*/ 
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
+*/
 
 #ifndef __LS_COLORS_H__
 #define __LS_COLORS_H__
 
 #include "gnome-cmd-file.h"
 
-typedef struct {
-	GnomeVFSFileType type;
-	gchar *ext;
-	GdkColor *fg, *bg;
+G_BEGIN_DECLS
+
+typedef struct
+{
+    GnomeVFSFileType type;
+    gchar *ext;
+    GdkColor *fg, *bg;
 } LsColor;
 
 void     ls_colors_init (void);
 LsColor *ls_colors_get (GnomeCmdFile *finfo);
 
-#endif //__LS_COLORS_H__
+G_END_DECLS
+
+#endif // __LS_COLORS_H__
