@@ -1,5 +1,5 @@
 /*
-    GNOME Commander - A GNOME based file manager 
+    GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
 
     This program is free software; you can redistribute it and/or modify
@@ -14,24 +14,27 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-*/ 
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
+*/
 
 #ifndef __PLUGIN_MANAGER_H__
 #define __PLUGIN_MANAGER_H__
 
 #include <gmodule.h>
 
-typedef struct {
-	gboolean active;
-	gboolean loaded;
-	gboolean autoload;
-	gchar *fname;
-	gchar *fpath;	
-	GnomeCmdPlugin *plugin;
-	PluginInfo *info;
-	GtkWidget *menu;
-	GModule *module;
+G_BEGIN_DECLS
+
+typedef struct
+{
+    gboolean active;
+    gboolean loaded;
+    gboolean autoload;
+    gchar *fname;
+    gchar *fpath;
+    GnomeCmdPlugin *plugin;
+    PluginInfo *info;
+    GtkWidget *menu;
+    GModule *module;
 } PluginData;
 
 
@@ -40,4 +43,6 @@ void plugin_manager_shutdown (void);
 GList *plugin_manager_get_all (void);
 void plugin_manager_show (void);
 
-#endif //__PLUGIN_MANAGER_H__
+G_END_DECLS
+
+#endif // __PLUGIN_MANAGER_H__
